@@ -1,6 +1,6 @@
 ###############################################################################
 #
-# This file copyright (c) 2008 by Randy J. Ray, all rights reserved
+# This file copyright (c) 2010 by Randy J. Ray, all rights reserved
 #
 # Copying and distribution are permitted under the terms of the Artistic
 # License 2.0 (http://www.opensource.org/licenses/artistic-license-2.0.php) or
@@ -20,30 +20,35 @@ package Image::Size;
 
 require 5.006;
 
+# These are the Perl::Critic policies that are being turned off globally:
+## no critic(RequireBriefOpen)
+## no critic(ProhibitAutomaticExportation)
+## no critic(ProhibitExplicitISA)
+
 use strict;
 use warnings;
 use bytes;
-use AutoLoader 'AUTOLOAD';
-require Exporter;
+use vars qw(
+    @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION $NO_CACHE %CACHE
+    $GIF_BEHAVIOR @TYPE_MAP %PCD_MAP $PCD_SCALE $READ_IN $LAST_POS
+);
 
-our (@ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS, $revision, $VERSION, $NO_CACHE,
-     $GIF_BEHAVIOR, %PCD_MAP, $PCD_SCALE, $read_in, $last_pos, %CACHE);
+use AutoLoader 'AUTOLOAD';
+use Exporter;
 
 BEGIN
 {
-
     @ISA         = qw(Exporter);
     @EXPORT      = qw(imgsize);
     @EXPORT_OK   = qw(imgsize html_imgsize attr_imgsize
                       %CACHE $NO_CACHE $PCD_SCALE $GIF_BEHAVIOR);
     %EXPORT_TAGS = ('all' => [ @EXPORT_OK ]);
 
-    $VERSION = "3.220";
-	$VERSION = eval $VERSION; ## no critic
+    $VERSION = '3.221';
+    $VERSION = eval $VERSION; ## no critic(ProhibitStringyEval)
 
     # Default behavior for GIFs is to return the "screen" size
     $GIF_BEHAVIOR = 0;
-
 }
 
 # This allows people to specifically request that the cache not be used
@@ -52,51 +57,54 @@ $NO_CACHE = 0;
 # Package lexicals - invisible to outside world, used only in imgsize
 #
 # Mapping of patterns to the sizing routines
-my %type_map = ( '^GIF8[79]a'               => \&gifsize,
-                 "^\xFF\xD8"                => \&jpegsize,
-                 "^\x89PNG\x0d\x0a\x1a\x0a" => \&pngsize,
-                 "^P[1-7]"                  => \&ppmsize, # also XVpics
-                 '\#define\s+\S+\s+\d+'     => \&xbmsize,
-                 '\/\* XPM \*\/'            => \&xpmsize,
-                 '^MM\x00\x2a'              => \&tiffsize,
-                 '^II\x2a\x00'              => \&tiffsize,
-                 '^BM'                      => \&bmpsize,
-                 '^8BPS'                    => \&psdsize,
-                 '^PCD_OPA'                 => \&pcdsize,
-                 '^FWS'                     => \&swfsize,
-                 '^CWS'                     => \&swfmxsize,
-                 "^\x8aMNG\x0d\x0a\x1a\x0a" => \&mngsize);
+@TYPE_MAP = (
+    qr{^GIF8[79]a}               => \&gifsize,
+    qr{^\xFF\xD8}                => \&jpegsize,
+    qr{^\x89PNG\x0d\x0a\x1a\x0a} => \&pngsize,
+    qr{^P[1-7]}                  => \&ppmsize, # also XVpics
+    qr{#define\s+\S+\s+\d+}      => \&xbmsize,
+    qr{/\* XPM \*/}              => \&xpmsize,
+    qr{^MM\x00\x2a}              => \&tiffsize,
+    qr{^II\x2a\x00}              => \&tiffsize,
+    qr{^BM}                      => \&bmpsize,
+    qr{^8BPS}                    => \&psdsize,
+    qr{^PCD_OPA}                 => \&pcdsize,
+    qr{^FWS}                     => \&swfsize,
+    qr{^CWS}                     => \&swfmxsize,
+    qr{^\x8aMNG\x0d\x0a\x1a\x0a} => \&mngsize,
+);
 # Kodak photo-CDs are weird. Don't ask me why, you really don't want details.
 %PCD_MAP = ( 'base/16' => [ 192,  128  ],
              'base/4'  => [ 384,  256  ],
              'base'    => [ 768,  512  ],
              'base4'   => [ 1536, 1024 ],
              'base16'  => [ 3072, 2048 ],
-             'base64'  => [ 6144, 4096 ] );
+             'base64'  => [ 6144, 4096 ], );
 # Default scale for PCD images
 $PCD_SCALE = 'base';
 
-#
 # These are lexically-scoped anonymous subroutines for reading the three
 # types of input streams. When the input to imgsize() is typed, then the
 # lexical "read_in" is assigned one of these, thus allowing the individual
 # routines to operate on these streams abstractly.
-#
 
 my $read_io = sub {
     my $handle = shift;
     my ($length, $offset) = @_;
 
-    if (defined($offset) && ($offset != $last_pos))
+    if (defined($offset) && ($offset != $LAST_POS))
     {
-        $last_pos = $offset;
-        return '' if (! seek($handle, $offset, 0));
+        $LAST_POS = $offset;
+        return q{} if (! seek $handle, $offset, 0);
     }
 
-    my ($data, $rtn) = ('', 0);
+    my ($data, $rtn) = (q{}, 0);
     $rtn = read $handle, $data, $length;
-    $data = '' unless ($rtn);
-    $last_pos = tell $handle;
+    if (! $rtn)
+    {
+        $data = q{};
+    }
+    $LAST_POS = tell $handle;
 
     $data;
 };
@@ -105,19 +113,19 @@ my $read_buf = sub {
     my $buf = shift;
     my ($length, $offset) = @_;
 
-    if (defined($offset) && ($offset != $last_pos))
+    if (defined($offset) && ($offset != $LAST_POS))
     {
-        $last_pos = $offset;
-        return '' if ($last_pos > length($$buf));
+        $LAST_POS = $offset;
+        return q{} if ($LAST_POS > length ${$buf});
     }
 
-    my $data = substr($$buf, $last_pos, $length);
-    $last_pos += length($data);
+    my $data = substr ${$buf}, $LAST_POS, $length;
+    $LAST_POS += length $data;
 
     $data;
 };
 
-sub imgsize
+sub imgsize ## no critic(ProhibitExcessComplexity)
 {
     my $stream = shift;
 
@@ -130,27 +138,24 @@ sub imgsize
     # This will contain the file name, if we got one
     my $file_name = undef;
 
-    $header = '';
+    $header = q{};
 
-    if (ref($stream) eq "SCALAR")
+    if (ref($stream) eq 'SCALAR')
     {
         $handle = $stream;
-        $read_in = $read_buf;
-        $header = substr(($$handle || ''), 0, 256);
+        $READ_IN = $read_buf;
+        $header = substr ${$handle} || q{}, 0, 256;
     }
     elsif (ref $stream)
     {
-        #
         # I no longer require $stream to be in the IO::* space. So I'm assuming
         # you don't hose yourself by passing a ref that can't do fileops. If
         # you do, you fix it.
-        #
         $handle = $stream;
-        $read_in = $read_io;
+        $READ_IN = $read_io;
         $save_pos = tell $handle;
         $need_restore = 1;
 
-        #
         # First alteration (didn't wait long, did I?) to the existant handle:
         #
         # assist dain-bramaged operating systems -- SWD
@@ -158,80 +163,95 @@ sub imgsize
         # that something else "owns" ... the change is global, and there
         # is no way to reverse it.
         # But image files ought to be handled as binary anyway.
-        #
-        binmode($handle);
-        seek($handle, 0, 0);
+        binmode $handle;
+        seek $handle, 0, 0;
         read $handle, $header, 256;
-        seek($handle, 0, 0);
+        seek $handle, 0, 0;
     }
     else
     {
-        unless ($NO_CACHE)
+        if (! $NO_CACHE)
         {
             require Cwd;
             require File::Spec;
 
-            $stream = File::Spec->catfile(Cwd::cwd(),$stream)
-                unless File::Spec->file_name_is_absolute($stream);
+            if (! File::Spec->file_name_is_absolute($stream))
+            {
+                $stream = File::Spec->catfile(Cwd::cwd(), $stream);
+            }
             $mtime = (stat $stream)[9];
             if (-e "$stream" and exists $CACHE{$stream})
             {
-                @list = split(/,/, $CACHE{$stream}, 4);
+                @list = split /,/, $CACHE{$stream}, 4;
 
                 # Don't return the cache if the file is newer.
-                return @list[1 .. 3] unless ($list[0] < $mtime);
+                if ($mtime <= $list[0])
+                {
+                    return @list[1 .. 3];
+                }
                 # In fact, clear it
                 delete $CACHE{$stream};
             }
         }
 
-        #first try to open the stream
+        # first try to open the stream
         require Symbol;
         $handle = Symbol::gensym();
-        open($handle, "<", $stream) or
+        if (! open $handle, '<', $stream)
+        {
             return (undef, undef, "Can't open image file $stream: $!");
+        }
 
         $need_close = 1;
         # assist dain-bramaged operating systems -- SWD
-        binmode($handle);
+        binmode $handle;
         read $handle, $header, 256;
-        seek($handle, 0, 0);
-        $read_in = $read_io;
+        seek $handle, 0, 0;
+        $READ_IN = $read_io;
         $file_name = $stream;
     }
-    $last_pos = 0;
+    $LAST_POS = 0;
 
-    #
     # Oh pessimism... set the values of $x and $y to the error condition. If
     # the grep() below matches the data to one of the known types, then the
     # called subroutine will override these...
-    #
-    $id = "Data stream is not a known image file format";
+    $id = 'Data stream is not a known image file format';
     $x  = undef;
     $y  = undef;
 
-    grep($header =~ /$_/ && (($x, $y, $id) = &{$type_map{$_}}($handle)),
-         keys %type_map);
+    my $tm_idx = 0;
+    while ($tm_idx < @TYPE_MAP)
+    {
+        if ($header =~ $TYPE_MAP[$tm_idx])
+        {
+            ($x, $y, $id) = $TYPE_MAP[$tm_idx + 1]->($handle);
+            last;
+        }
+        $tm_idx += 2;
+    }
 
-    #
     # Added as an afterthought: I'm probably not the only one who uses the
     # same shaded-sphere image for several items on a bulleted list:
-    #
-    $CACHE{$stream} = join(',', $mtime, $x, $y, $id)
-        unless ($NO_CACHE or (ref $stream) or (! defined $x));
+    if (! ($NO_CACHE or (ref $stream) or (! defined $x)))
+    {
+        $CACHE{$stream} = join q{,}, $mtime, $x, $y, $id;
+    }
 
-    #
     # If we were passed an existant file handle, we need to restore the
     # old filepos:
-    #
-    seek($handle, $save_pos, 0) if $need_restore;
+    if ($need_restore)
+    {
+        seek $handle, $save_pos, 0;
+    }
     # ...and if we opened the file ourselves, we need to close it
-    close($handle) if $need_close;
+    if ($need_close)
+    {
+        close $handle; ## no critic(RequireCheckedClose)
+    }
 
-    #
     # Image::Magick operates on file names.
-    #
-    if ($file_name && ! defined($x) && ! defined($y)) {
+    if ($file_name && (! defined $x) && (! defined $y))
+    {
         ($x, $y, $id) = imagemagick_size($file_name);
     }
 
@@ -240,27 +260,33 @@ sub imgsize
     return (wantarray) ? ($x, $y, $id) : ();
 }
 
-sub imagemagick_size {
+sub imagemagick_size
+{
+    my $file_name = shift;
+
     my $module_name;
     # First see if we have already loaded Graphics::Magick or Image::Magick
     # If so, just use whichever one is already loaded.
-    if (exists $INC{'Graphics/Magick.pm'}) {
+    if (exists $INC{'Graphics/Magick.pm'})
+    {
         $module_name = 'Graphics::Magick';
     }
-    elsif (exists $INC{'Image/Magick.pm'}) {
+    elsif (exists $INC{'Image/Magick.pm'})
+    {
         $module_name = 'Image::Magick';
     }
-
     # If neither are already loaded, try loading either one.
-    elsif ( _load_magick_module('Graphics::Magick') ) {
+    elsif (_load_magick_module('Graphics::Magick'))
+    {
        $module_name = 'Graphics::Magick';
     }
-    elsif ( _load_magick_module('Image::Magick') ) {
+    elsif (_load_magick_module('Image::Magick'))
+    {
        $module_name = 'Image::Magick';
     }
 
-    if ($module_name) {
-        my ($file_name) = @_;
+    if ($module_name)
+    {
         my $img = $module_name->new();
         my $x = $img->Read($file_name);
         # Image::Magick error handling is a bit weird, see
@@ -273,24 +299,26 @@ sub imagemagick_size {
 
     }
     else {
-        return (undef, undef, "Data stream is not a known image file format");
+        return (undef, undef, 'Data stream is not a known image file format');
     }
 }
 
 # load Graphics::Magick or Image::Magick if one is not already loaded.
 sub _load_magick_module {
     my $module_name = shift;
-    eval {
-        local $SIG{__DIE__};
+    my $retval = eval {
+        local $SIG{__DIE__} = q{};
         require $module_name;
+        1;
     };
-    return !$@;
+    return $retval ? 1 : 0;
 }
 
 
 sub html_imgsize
 {
-    my @args = imgsize(@_);
+    my @args = @_;
+    @args = imgsize(@args);
 
     # Use lowercase and quotes so that it works with xhtml.
     return ((defined $args[0]) ?
@@ -300,7 +328,8 @@ sub html_imgsize
 
 sub attr_imgsize
 {
-    my @args = imgsize(@_);
+    my @args = @_;
+    @args = imgsize(@args);
 
     return ((defined $args[0]) ?
             (('-width', '-height', @args)[0, 2, 1, 3]) :
@@ -312,13 +341,24 @@ sub img_eof
 {
     my $stream = shift;
 
-    return ($last_pos >= length($$stream)) if (ref($stream) eq "SCALAR");
+    if (ref($stream) eq 'SCALAR')
+    {
+        return ($LAST_POS >= length ${$stream});
+    }
 
-    eof $stream;
+    return eof $stream;
 }
 
 # Simple converter-routine used by SWF and CWS code
-sub _bin2int { unpack("N", pack("B32", substr("0" x 32 . shift, -32))); }
+sub _bin2int
+{
+    my $val = shift;
+    return unpack 'N', pack 'B32', substr(('0' x 32) . $val, -32); ## no critic (ProhibitParensWithBuiltins)
+}
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -355,6 +395,8 @@ Alex Knowles I<(alex@ed.ac.uk)>, a tool to examine HTML and add 'width' and
 file name, so multiple calls on the same file name (such as images used
 in bulleted lists, for example) do not result in repeated computations.
 
+=head1 SUBROUTINES/METHODS
+
 B<Image::Size> provides three interfaces for possible import:
 
 =over
@@ -719,7 +761,7 @@ restricted to cases where the input to C<imgsize> is provided as file name.
 L<Image::Magick> and L<Image::Info> Perl modules at CPAN. The
 B<Graphics::Magick> Perl API at L<http://www.graphicsmagick.org/perl.html>.
 
-=head1 AUTHORS
+=head1 CONTRIBUTORS
 
 Perl module interface by Randy J. Ray I<(rjray@blackperl.com)>, original
 image-sizing code by Alex Knowles I<(alex@ed.ac.uk)> and Andrew Tong
@@ -781,7 +823,7 @@ L<http://github.com/rjray/image-size>
 
 =back
 
-=head1 COPYRIGHT & LICENSE
+=head1 LICENSE AND COPYRIGHT
 
 This file and the code within are copyright (c) 1996-2009 by Randy J. Ray.
 
@@ -789,12 +831,12 @@ Copying and distribution are permitted under the terms of the Artistic
 License 2.0 (L<http://www.opensource.org/licenses/artistic-license-2.0.php>) or
 the GNU LGPL 2.1 (L<http://www.opensource.org/licenses/lgpl-2.1.php>).
 
+=head1 AUTHOR
+
+Randy J. Ray C<< <rjray@blackperl.com> >>
+
 =cut
 
-1;
-
-__END__
-
 ###########################################################################
 # Subroutine gets the size of the specified GIF
 ###########################################################################
@@ -802,39 +844,40 @@ sub gifsize
 {
     my $stream = shift;
 
-    my ($cmapsize, $buf, $sh, $sw, $h, $w, $x, $y, $type);
+    my ($cmapsize, $buf, $sh, $sw, $x, $y, $type);
 
     my $gif_blockskip = sub {
-        my ($skip, $type) = @_;
+        my ($skip, $blocktype) = @_;
         my ($lbuf);
 
-        &$read_in($stream, $skip);        # Skip header (if any)
+        $READ_IN->($stream, $skip);        # Skip header (if any)
         while (1)
         {
-            if (&img_eof($stream))
+            if (img_eof($stream))
             {
                 return (undef, undef,
-                        "Invalid/Corrupted GIF (at EOF in GIF $type)");
+                        "Invalid/Corrupted GIF (at EOF in GIF $blocktype)");
             }
-            $lbuf = &$read_in($stream, 1);        # Block size
-            last if ord($lbuf) == 0;     # Block terminator
-            &$read_in($stream, ord($lbuf));  # Skip data
+            $lbuf = $READ_IN->($stream, 1);  # Block size
+            last if ord($lbuf) == 0;         # Block terminator
+            $READ_IN->($stream, ord $lbuf);  # Skip data
         }
     };
 
-    return (undef, undef,
-            'Out-of-range value for $Image::Size::GIF_BEHAVIOR: ' .
-            $Image::Size::GIF_BEHAVIOR)
-        if ($Image::Size::GIF_BEHAVIOR > 2);
+    if ($GIF_BEHAVIOR > 2)
+    {
+        return (undef, undef,
+                "\$Image::Size::GIF_BEHAVIOR out of range: $GIF_BEHAVIOR");
+    }
 
     # Skip over the identifying string, since we already know this is a GIF
-    $type = &$read_in($stream, 6);
-    if (length($buf = &$read_in($stream, 7)) != 7 )
+    $type = $READ_IN->($stream, 6);
+    if (length($buf = $READ_IN->($stream, 7)) != 7 )
     {
-        return (undef, undef, "Invalid/Corrupted GIF (bad header)");
+        return (undef, undef, 'Invalid/Corrupted GIF (bad header)');
     }
-    ($sw, $sh, $x) = unpack("vv C", $buf);
-    if ($Image::Size::GIF_BEHAVIOR == 0)
+    ($sw, $sh, $x) = unpack 'vv C', $buf;
+    if ($GIF_BEHAVIOR == 0)
     {
         return ($sw, $sh, 'GIF');
     }
@@ -842,10 +885,10 @@ sub gifsize
     if ($x & 0x80)
     {
         $cmapsize = 3 * (2**(($x & 0x07) + 1));
-        if (! &$read_in($stream, $cmapsize))
+        if (! $READ_IN->($stream, $cmapsize))
         {
             return (undef, undef,
-                    "Invalid/Corrupted GIF (global color map too small?)");
+                    'Invalid/Corrupted GIF (global color map too small?)');
         }
     }
 
@@ -856,7 +899,7 @@ sub gifsize
   FINDIMAGE:
     while (1)
     {
-        if (&img_eof($stream))
+        if (img_eof($stream))
         {
             # At this point, if we haven't returned then the user wants the
             # largest of the sub-images. So, if $sh and $sw are still 0s, then
@@ -869,21 +912,21 @@ sub gifsize
             else
             {
                 return (undef, undef,
-                        "Invalid/Corrupted GIF (no Image Descriptors)");
+                        'Invalid/Corrupted GIF (no Image Descriptors)');
             }
         }
-        $buf = &$read_in($stream, 1);
-        ($x) = unpack("C", $buf);
+        $buf = $READ_IN->($stream, 1);
+        ($x) = unpack 'C', $buf;
         if ($x == 0x2c)
         {
             # Image Descriptor (GIF87a, GIF89a 20.c.i)
-            if (length($buf = &$read_in($stream, 8)) != 8)
+            if (length($buf = $READ_IN->($stream, 8)) != 8)
             {
                 return (undef, undef,
-                        "Invalid/Corrupted GIF (missing image header?)");
+                        'Invalid/Corrupted GIF (missing image header?)');
             }
-            ($x, $y) = unpack("x4 vv", $buf);
-            return ($x, $y, 'GIF') if ($Image::Size::GIF_BEHAVIOR == 1);
+            ($x, $y) = unpack 'x4 vv', $buf;
+            return ($x, $y, 'GIF') if ($GIF_BEHAVIOR == 1);
             if ($x > $sw and $y > $sh)
             {
                 $sw = $x;
@@ -893,46 +936,47 @@ sub gifsize
         if ($x == 0x21)
         {
             # Extension Introducer (GIF89a 23.c.i, could also be in GIF87a)
-            $buf = &$read_in($stream, 1);
-            ($x) = unpack("C", $buf);
+            $buf = $READ_IN->($stream, 1);
+            ($x) = unpack 'C', $buf;
             if ($x == 0xF9)
             {
                 # Graphic Control Extension (GIF89a 23.c.ii)
-                &$read_in($stream, 6);    # Skip it
+                $READ_IN->($stream, 6);    # Skip it
                 next FINDIMAGE;       # Look again for Image Descriptor
             }
             elsif ($x == 0xFE)
             {
                 # Comment Extension (GIF89a 24.c.ii)
-                &$gif_blockskip(0, "Comment");
+                $gif_blockskip->(0, 'Comment');
                 next FINDIMAGE;       # Look again for Image Descriptor
             }
             elsif ($x == 0x01)
             {
                 # Plain Text Label (GIF89a 25.c.ii)
-                &$gif_blockskip(13, "text data");
+                $gif_blockskip->(13, 'text data');
                 next FINDIMAGE;       # Look again for Image Descriptor
             }
             elsif ($x == 0xFF)
             {
                 # Application Extension Label (GIF89a 26.c.ii)
-                &$gif_blockskip(12, "application data");
+                $gif_blockskip->(12, 'application data');
                 next FINDIMAGE;       # Look again for Image Descriptor
             }
             else
             {
                 return (undef, undef,
-                        sprintf("Invalid/Corrupted GIF (Unknown " .
-                                "extension %#x)", $x));
+                        sprintf 'Invalid/Corrupted GIF (Unknown ' .
+                                'extension %#x)', $x);
             }
         }
         else
         {
             return (undef, undef,
-                    sprintf("Invalid/Corrupted GIF (Unknown code %#x)",
-                            $x));
+                    sprintf 'Invalid/Corrupted GIF (Unknown code %#x)', $x);
         }
     }
+
+    return (undef, undef, 'gifsize fell through to the end, error');
 }
 
 sub xbmsize
@@ -940,16 +984,16 @@ sub xbmsize
     my $stream = shift;
 
     my $input;
-    my ($x, $y, $id) = (undef, undef, "Could not determine XBM size");
+    my ($x, $y, $id) = (undef, undef, 'Could not determine XBM size');
 
-    $input = &$read_in($stream, 1024);
-    if ($input =~ /^\#define\s*\S*\s*(\d+)\s*\n\#define\s*\S*\s*(\d+)/si)
+    $input = $READ_IN->($stream, 1024);
+    if ($input =~ /^\#define\s*\S*\s*(\d+)\s*\n\#define\s*\S*\s*(\d+)/ix)
     {
         ($x, $y) = ($1, $2);
         $id = 'XBM';
     }
 
-    ($x, $y, $id);
+    return ($x, $y, $id);
 }
 
 # Added by Randy J. Ray, 30 Jul 1996
@@ -961,20 +1005,21 @@ sub xpmsize
     my $stream = shift;
 
     my $line;
-    my ($x, $y, $id) = (undef, undef, "Could not determine XPM size");
+    my ($x, $y, $id) = (undef, undef, 'Could not determine XPM size');
 
-    while ($line = &$read_in($stream, 1024))
+    while ($line = $READ_IN->($stream, 1024))
     {
-        next unless ($line =~ /"\s*(\d+)\s+(\d+)(\s+\d+\s+\d+){1,2}\s*"/s);
-        ($x, $y) = ($1, $2);
-        $id = 'XPM';
-        last;
+        if ($line =~ /"\s*(\d+)\s+(\d+)(\s+\d+\s+\d+){1,2}\s*"/)
+        {
+            ($x, $y) = ($1, $2);
+            $id = 'XPM';
+            last;
+        }
     }
 
-    ($x, $y, $id);
+    return ($x, $y, $id);
 }
 
-
 # pngsize : gets the width & height (in pixels) of a png file
 # cor this program is on the cutting edge of technology! (pity it's blunt!)
 #
@@ -983,20 +1028,20 @@ sub pngsize
 {
     my $stream = shift;
 
-    my ($x, $y, $id) = (undef, undef, "could not determine PNG size");
+    my ($x, $y, $id) = (undef, undef, 'Could not determine PNG size');
     my ($offset, $length);
 
     # Offset to first Chunk Type code = 8-byte ident + 4-byte chunk length + 1
     $offset = 12; $length = 4;
-    if (&$read_in($stream, $length, $offset) eq 'IHDR')
+    if ($READ_IN->($stream, $length, $offset) eq 'IHDR')
     {
         # IHDR = Image Header
         $length = 8;
-        ($x, $y) = unpack("NN", &$read_in($stream, $length));
+        ($x, $y) = unpack 'NN', $READ_IN->($stream, $length);
         $id = 'PNG';
     }
 
-    ($x, $y, $id);
+    return ($x, $y, $id);
 }
 
 # mngsize: gets the width and height (in pixels) of an MNG file.
@@ -1007,20 +1052,20 @@ sub mngsize
 {
     my $stream = shift;
 
-    my ($x, $y, $id) = (undef, undef, "could not determine MNG size");
+    my ($x, $y, $id) = (undef, undef, 'Could not determine MNG size');
     my ($offset, $length);
 
     # Offset to first Chunk Type code = 8-byte ident + 4-byte chunk length + 1
     $offset = 12; $length = 4;
-    if (&$read_in($stream, $length, $offset) eq 'MHDR')
+    if ($READ_IN->($stream, $length, $offset) eq 'MHDR')
     {
         # MHDR = Image Header
         $length = 8;
-        ($x, $y) = unpack("NN", &$read_in($stream, $length));
+        ($x, $y) = unpack 'NN', $READ_IN->($stream, $length);
         $id = 'MNG';
     }
 
-    ($x, $y, $id);
+    return ($x, $y, $id);
 }
 
 # jpegsize: gets the width and height (in pixels) of a jpeg file
@@ -1032,49 +1077,49 @@ sub jpegsize
 {
     my $stream = shift;
 
-    my $MARKER      = "\xFF";       # Section marker.
+    my $MARKER     = chr 0xff; # Section marker
 
-    my $SIZE_FIRST  = 0xC0;         # Range of segment identifier codes
-    my $SIZE_LAST   = 0xC3;         #  that hold size info.
+    my $SIZE_FIRST = 0xC0;   # Range of segment identifier codes
+    my $SIZE_LAST  = 0xC3;   #  that hold size info.
 
-    my ($x, $y, $id) = (undef, undef, "could not determine JPEG size");
+    my ($x, $y, $id) = (undef, undef, 'Could not determine JPEG size');
 
     my ($marker, $code, $length);
     my $segheader;
 
     # Dummy read to skip header ID
-    &$read_in($stream, 2);
+    $READ_IN->($stream, 2);
     while (1)
     {
         $length = 4;
-        $segheader = &$read_in($stream, $length);
+        $segheader = $READ_IN->($stream, $length);
 
         # Extract the segment header.
-        ($marker, $code, $length) = unpack("a a n", $segheader);
+        ($marker, $code, $length) = unpack 'a a n', $segheader;
 
         # Verify that it's a valid segment.
         if ($marker ne $MARKER)
         {
             # Was it there?
-            $id = "JPEG marker not found";
+            $id = 'JPEG marker not found';
             last;
         }
         elsif ((ord($code) >= $SIZE_FIRST) && (ord($code) <= $SIZE_LAST))
         {
             # Segments that contain size info
             $length = 5;
-            ($y, $x) = unpack("xnn", &$read_in($stream, $length));
+            ($y, $x) = unpack 'xnn', $READ_IN->($stream, $length);
             $id = 'JPG';
             last;
         }
         else
         {
             # Dummy read to skip over data
-            &$read_in($stream, ($length - 2));
+            $READ_IN->($stream, ($length - 2));
         }
     }
 
-    ($x, $y, $id);
+    return ($x, $y, $id);
 }
 
 # ppmsize: gets data on the PPM/PGM/PBM family.
@@ -1084,99 +1129,123 @@ sub ppmsize
 {
     my $stream = shift;
 
-    my ($x, $y, $id) = (undef, undef,
-                        "Unable to determine size of PPM/PGM/PBM data");
+    my ($x, $y, $id) =
+        (undef, undef, 'Unable to determine size of PPM/PGM/PBM data');
     my $n;
+    my @table = qw(nil PBM PGM PPM PBM PGM PPM);
 
-    my $header = &$read_in($stream, 1024);
+    my $header = $READ_IN->($stream, 1024);
 
     # PPM file of some sort
     $header =~ s/^\#.*//mg;
-    ($n, $x, $y) = ($header =~ /^(P[1-6])\s+(\d+)\s+(\d+)/s);
-    $id = "PBM" if $n eq "P1" || $n eq "P4";
-    $id = "PGM" if $n eq "P2" || $n eq "P5";
-    $id = "PPM" if $n eq "P3" || $n eq "P6";
-    if ($n eq 'P7')
+    if ($header =~ /^(?:P([1-7]))\s+(\d+)\s+(\d+)/)
     {
-        # John Bradley's XV thumbnail pics (thanks to inwap@jomis.Tymnet.COM)
-        $id = 'XV';
-        ($x, $y) = ($header =~ /IMGINFO:(\d+)x(\d+)/s);
+        ($n, $x, $y) = ($1, $2, $3);
+
+        if ($n == 7)
+        {
+            # John Bradley's XV thumbnail pics (from inwap@jomis.Tymnet.COM)
+            $id = 'XV';
+            ($x, $y) = ($header =~ /IMGINFO:(\d+)x(\d+)/s);
+        }
+        else
+        {
+            $id = $table[$n];
+        }
     }
 
-    ($x, $y, $id);
+    return ($x, $y, $id);
 }
 
 # tiffsize: size a TIFF image
 #
 # Contributed by Cloyce Spradling <cloyce@headgear.org>
-sub tiffsize {
+sub tiffsize
+{
     my $stream = shift;
 
-    my ($x, $y, $id) = (undef, undef, "Unable to determine size of TIFF data");
+    my ($x, $y, $id) = (undef, undef, 'Unable to determine size of TIFF data');
 
     my $endian = 'n';           # Default to big-endian; I like it better
-    my $header = &$read_in($stream, 4);
-    $endian = 'v' if ($header =~ /II\x2a\x00/o); # little-endian
+    my $header = $READ_IN->($stream, 4);
+    if ($header =~ /II\x2a\x00/o)
+    {
+        # little-endian
+        $endian = 'v';
+    }
 
     # Set up an association between data types and their corresponding
     # pack/unpack specification.  Don't take any special pains to deal with
     # signed numbers; treat them as unsigned because none of the image
-    # dimensions should ever be negative.  (I hope.)
-    my @packspec = ( undef,     # nothing (shouldn't happen)
-                     'C',       # BYTE (8-bit unsigned integer)
-                     undef,     # ASCII
-                     $endian,   # SHORT (16-bit unsigned integer)
-                     uc($endian), # LONG (32-bit unsigned integer)
-                     undef,     # RATIONAL
-                     'c',       # SBYTE (8-bit signed integer)
-                     undef,     # UNDEFINED
-                     $endian,   # SSHORT (16-bit unsigned integer)
-                     uc($endian), # SLONG (32-bit unsigned integer)
+    # dimensions should ever be negative. (I hope.)
+    my @packspec = ( undef,      # nothing (shouldn't happen)
+                     'C',        # BYTE (8-bit unsigned integer)
+                     undef,      # ASCII
+                     $endian,    # SHORT (16-bit unsigned integer)
+                     uc $endian, # LONG (32-bit unsigned integer)
+                     undef,      # RATIONAL
+                     'c',        # SBYTE (8-bit signed integer)
+                     undef,      # UNDEFINED
+                     $endian,    # SSHORT (16-bit unsigned integer)
+                     uc $endian, # SLONG (32-bit unsigned integer)
                      );
 
-    my $offset = &$read_in($stream, 4, 4); # Get offset to IFD
-    $offset = unpack(uc($endian), $offset); # Fix it so we can use it
+    my $offset = $READ_IN->($stream, 4, 4); # Get offset to IFD
+    $offset = unpack uc $endian, $offset; # Fix it so we can use it
 
-    my $ifd = &$read_in($stream, 2, $offset); # Get number of directory entries
-    my $num_dirent = unpack($endian, $ifd); # Make it useful
+    my $ifd = $READ_IN->($stream, 2, $offset); # Get num. of directory entries
+    my $num_dirent = unpack $endian, $ifd; # Make it useful
     $offset += 2;
     $num_dirent = $offset + ($num_dirent * 12); # Calc. maximum offset of IFD
 
     # Do all the work
-    $ifd = '';
+    $ifd = q{};
     my $tag = 0;
     my $type = 0;
-    while (!defined($x) || !defined($y)) {
-        $ifd = &$read_in($stream, 12, $offset); # Get first directory entry
-        last if (($ifd eq '') || ($offset > $num_dirent));
+    while ((! defined $x) || (! defined$y)) {
+        $ifd = $READ_IN->($stream, 12, $offset);   # Get first directory entry
+        last if (($ifd eq q{}) || ($offset > $num_dirent));
         $offset += 12;
-        $tag = unpack($endian, $ifd); # ...and decode its tag
-        $type = unpack($endian, substr($ifd, 2, 2)); # ...and the data type
+        $tag = unpack $endian, $ifd;               # ...and decode its tag
+        $type = unpack $endian, substr $ifd, 2, 2; # ...and the data type
         # Check the type for sanity.
-        next if (($type > @packspec+0) || (!defined($packspec[$type])));
-        if ($tag == 0x0100) {   # ImageWidth (x)
+        next if (($type > @packspec+0) || (! defined $packspec[$type]));
+        if ($tag == 0x0100)    # ImageWidth (x)
+        {
             # Decode the value
-            $x = unpack($packspec[$type], substr($ifd, 8, 4));
-        } elsif ($tag == 0x0101) {      # ImageLength (y)
+            $x = unpack $packspec[$type], substr $ifd, 8, 4;
+        }
+        elsif ($tag == 0x0101) # ImageLength (y)
+        {
             # Decode the value
-            $y = unpack($packspec[$type], substr($ifd, 8, 4));
+            $y = unpack $packspec[$type], substr $ifd, 8, 4;
         }
     }
 
     # Decide if we were successful or not
-    if (defined($x) && defined($y)) {
+    if (defined $x and defined $y)
+    {
         $id = 'TIF';
-    } else {
-        $id = '';
-        $id = 'ImageWidth ' if (!defined($x));
-        if (!defined ($y)) {
-            $id .= 'and ' if ($id ne '');
+    }
+    else
+    {
+        $id = q{};
+        if (! defined $x)
+        {
+            $id = 'ImageWidth ';
+        }
+        if (! defined $y)
+        {
+            if ($id ne q{})
+            {
+                $id .= 'and ';
+            }
             $id .= 'ImageLength ';
         }
         $id .= 'tag(s) could not be found';
     }
 
-    ($x, $y, $id);
+    return ($x, $y, $id);
 }
 
 # bmpsize: size a Windows-ish BitMaP image
@@ -1186,14 +1255,17 @@ sub bmpsize
 {
     my $stream = shift;
 
-    my ($x, $y, $id) = (undef, undef, "Unable to determine size of BMP data");
-    my ($buffer);
+    my ($x, $y, $id) = (undef, undef, 'Unable to determine size of BMP data');
+    my $buffer;
 
-    $buffer = &$read_in($stream, 26);
-    ($x, $y) = unpack("x18VV", $buffer);
-    $id = 'BMP' if (defined $x and defined $y);
+    $buffer = $READ_IN->($stream, 26);
+    ($x, $y) = unpack 'x18VV', $buffer;
+    if (defined $x and defined $y)
+    {
+        $id = 'BMP';
+    }
 
-    ($x, $y, $id);
+    return ($x, $y, $id);
 }
 
 # psdsize: determine the size of a PhotoShop save-file (*.PSD)
@@ -1201,14 +1273,17 @@ sub psdsize
 {
     my $stream = shift;
 
-    my ($x, $y, $id) = (undef, undef, "Unable to determine size of PSD data");
-    my ($buffer);
+    my ($x, $y, $id) = (undef, undef, 'Unable to determine size of PSD data');
+    my $buffer;
 
-    $buffer = &$read_in($stream, 26);
-    ($y, $x) = unpack("x14NN", $buffer);
-    $id = 'PSD' if (defined $x and defined $y);
+    $buffer = $READ_IN->($stream, 26);
+    ($y, $x) = unpack 'x14NN', $buffer;
+    if (defined $x and defined $y)
+    {
+        $id = 'PSD';
+    }
 
-    ($x, $y, $id);
+    return ($x, $y, $id);
 }
 
 # swfsize: determine size of ShockWave/Flash files. Adapted from code sent by
@@ -1216,13 +1291,13 @@ sub psdsize
 sub swfsize
 {
     my $image  = shift;
-    my $header = &$read_in($image, 33);
+    my $header = $READ_IN->($image, 33);
 
-    my $ver = _bin2int(unpack 'B8', substr($header, 3, 1));
-    my $bs = unpack 'B133', substr($header, 8, 17);
-    my $bits = _bin2int(substr($bs, 0, 5));
-    my $x = int(_bin2int(substr($bs, 5+$bits, $bits))/20);
-    my $y = int(_bin2int(substr($bs, 5+$bits*3, $bits))/20);
+    my $ver = _bin2int(unpack 'B8', substr $header, 3, 1);
+    my $bs = unpack 'B133', substr $header, 8, 17;
+    my $bits = _bin2int(substr $bs, 0, 5);
+    my $x = int _bin2int(substr $bs, 5+$bits, $bits)/20;
+    my $y = int _bin2int(substr $bs, 5+$bits*3, $bits)/20;
 
     return ($x, $y, 'SWF');
 }
@@ -1234,13 +1309,16 @@ sub pcdsize
 {
     my $stream = shift;
 
-    my ($x, $y, $id) = (undef, undef, "Unable to determine size of PCD data");
-    my $buffer = &$read_in($stream, 0xf00);
+    my ($x, $y, $id) = (undef, undef, 'Unable to determine size of PCD data');
+    my $buffer = $READ_IN->($stream, 0xf00);
 
     # Second-tier sanity check
-    return ($x, $y, $id) unless (substr($buffer, 0x800, 3) eq 'PCD');
+    if (substr($buffer, 0x800, 3) ne 'PCD')
+    {
+        return ($x, $y, $id);
+    }
 
-    my $orient = ord(substr($buffer, 0x0e02, 1)) & 1; # Clear down to one bit
+    my $orient = ord(substr $buffer, 0x0e02, 1) & 1; # Clear down to one bit
     ($x, $y) = @{$Image::Size::PCD_MAP{lc $Image::Size::PCD_SCALE}}
         [($orient ? (0, 1) : (1, 0))];
 
@@ -1251,21 +1329,29 @@ sub pcdsize
 # from code sent by Victor Kuriashkin <victor@yasp.com>
 sub swfmxsize
 {
-    eval 'require Compress::Zlib;';
-    return (undef, undef, "Error loading Compress::Zlib: $@") if $@;
+    my $image = shift;
 
-    my ($image) = @_;
-    my $header = &$read_in($image, 1058);
-    my $ver = _bin2int(unpack 'B8', substr($header, 3, 1));
+    my $retval = eval {
+        local $SIG{__DIE__} = q{};
+        require Compress::Zlib;
+        1;
+    };
+    if (! $retval)
+    {
+        return (undef, undef, "Error loading Compress::Zlib: $@");
+    }
+
+    my $header = $READ_IN->($image, 1058);
+    my $ver = _bin2int(unpack 'B8', substr $header, 3, 1);
 
     my ($d, $status) = Compress::Zlib::inflateInit();
-    $header = substr($header, 8, 1024);
+    $header = substr $header, 8, 1024;
     $header = $d->inflate($header);
 
-    my $bs = unpack 'B133', substr($header, 0, 9);
-    my $bits = _bin2int(substr($bs, 0, 5));
-    my $x = int(_bin2int(substr($bs, 5+$bits, $bits))/20);
-    my $y = int(_bin2int(substr($bs, 5+$bits*3, $bits))/20);
+    my $bs = unpack 'B133', substr $header, 0, 9;
+    my $bits = _bin2int(substr $bs, 0, 5);
+    my $x = int _bin2int(substr $bs, 5+$bits, $bits)/20;
+    my $y = int _bin2int(substr $bs, 5+$bits*3, $bits)/20;
 
     return ($x, $y, 'CWS');
 }
